# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Receipt(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "date": "date[ms-format]",
        "contact": "Contact",
        "line_items": "list[LineItem]",
        "user": "User",
        "reference": "str",
        "line_amount_types": "LineAmountTypes",
        "sub_total": "float",
        "total_tax": "float",
        "total": "float",
        "receipt_id": "str",
        "status": "str",
        "receipt_number": "str",
        "updated_date_utc": "datetime[ms-format]",
        "has_attachments": "bool",
        "url": "str",
        "validation_errors": "list[ValidationError]",
        "warnings": "list[ValidationError]",
        "attachments": "list[Attachment]",
    }

    attribute_map = {
        "date": "Date",
        "contact": "Contact",
        "line_items": "LineItems",
        "user": "User",
        "reference": "Reference",
        "line_amount_types": "LineAmountTypes",
        "sub_total": "SubTotal",
        "total_tax": "TotalTax",
        "total": "Total",
        "receipt_id": "ReceiptID",
        "status": "Status",
        "receipt_number": "ReceiptNumber",
        "updated_date_utc": "UpdatedDateUTC",
        "has_attachments": "HasAttachments",
        "url": "Url",
        "validation_errors": "ValidationErrors",
        "warnings": "Warnings",
        "attachments": "Attachments",
    }

    def __init__(
        self,
        date=None,
        contact=None,
        line_items=None,
        user=None,
        reference=None,
        line_amount_types=None,
        sub_total=None,
        total_tax=None,
        total=None,
        receipt_id=None,
        status=None,
        receipt_number=None,
        updated_date_utc=None,
        has_attachments=False,
        url=None,
        validation_errors=None,
        warnings=None,
        attachments=None,
    ):  # noqa: E501
        """Receipt - a model defined in OpenAPI"""  # noqa: E501

        self._date = None
        self._contact = None
        self._line_items = None
        self._user = None
        self._reference = None
        self._line_amount_types = None
        self._sub_total = None
        self._total_tax = None
        self._total = None
        self._receipt_id = None
        self._status = None
        self._receipt_number = None
        self._updated_date_utc = None
        self._has_attachments = None
        self._url = None
        self._validation_errors = None
        self._warnings = None
        self._attachments = None
        self.discriminator = None

        if date is not None:
            self.date = date
        if contact is not None:
            self.contact = contact
        if line_items is not None:
            self.line_items = line_items
        if user is not None:
            self.user = user
        if reference is not None:
            self.reference = reference
        if line_amount_types is not None:
            self.line_amount_types = line_amount_types
        if sub_total is not None:
            self.sub_total = sub_total
        if total_tax is not None:
            self.total_tax = total_tax
        if total is not None:
            self.total = total
        if receipt_id is not None:
            self.receipt_id = receipt_id
        if status is not None:
            self.status = status
        if receipt_number is not None:
            self.receipt_number = receipt_number
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if has_attachments is not None:
            self.has_attachments = has_attachments
        if url is not None:
            self.url = url
        if validation_errors is not None:
            self.validation_errors = validation_errors
        if warnings is not None:
            self.warnings = warnings
        if attachments is not None:
            self.attachments = attachments

    @property
    def date(self):
        """Gets the date of this Receipt.  # noqa: E501

        Date of receipt – YYYY-MM-DD  # noqa: E501

        :return: The date of this Receipt.  # noqa: E501
        :rtype: date
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this Receipt.

        Date of receipt – YYYY-MM-DD  # noqa: E501

        :param date: The date of this Receipt.  # noqa: E501
        :type: date
        """

        self._date = date

    @property
    def contact(self):
        """Gets the contact of this Receipt.  # noqa: E501


        :return: The contact of this Receipt.  # noqa: E501
        :rtype: Contact
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """Sets the contact of this Receipt.


        :param contact: The contact of this Receipt.  # noqa: E501
        :type: Contact
        """

        self._contact = contact

    @property
    def line_items(self):
        """Gets the line_items of this Receipt.  # noqa: E501


        :return: The line_items of this Receipt.  # noqa: E501
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this Receipt.


        :param line_items: The line_items of this Receipt.  # noqa: E501
        :type: list[LineItem]
        """

        self._line_items = line_items

    @property
    def user(self):
        """Gets the user of this Receipt.  # noqa: E501


        :return: The user of this Receipt.  # noqa: E501
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Receipt.


        :param user: The user of this Receipt.  # noqa: E501
        :type: User
        """

        self._user = user

    @property
    def reference(self):
        """Gets the reference of this Receipt.  # noqa: E501

        Additional reference number  # noqa: E501

        :return: The reference of this Receipt.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this Receipt.

        Additional reference number  # noqa: E501

        :param reference: The reference of this Receipt.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def line_amount_types(self):
        """Gets the line_amount_types of this Receipt.  # noqa: E501


        :return: The line_amount_types of this Receipt.  # noqa: E501
        :rtype: LineAmountTypes
        """
        return self._line_amount_types

    @line_amount_types.setter
    def line_amount_types(self, line_amount_types):
        """Sets the line_amount_types of this Receipt.


        :param line_amount_types: The line_amount_types of this Receipt.  # noqa: E501
        :type: LineAmountTypes
        """

        self._line_amount_types = line_amount_types

    @property
    def sub_total(self):
        """Gets the sub_total of this Receipt.  # noqa: E501

        Total of receipt excluding taxes  # noqa: E501

        :return: The sub_total of this Receipt.  # noqa: E501
        :rtype: float
        """
        return self._sub_total

    @sub_total.setter
    def sub_total(self, sub_total):
        """Sets the sub_total of this Receipt.

        Total of receipt excluding taxes  # noqa: E501

        :param sub_total: The sub_total of this Receipt.  # noqa: E501
        :type: float
        """

        self._sub_total = sub_total

    @property
    def total_tax(self):
        """Gets the total_tax of this Receipt.  # noqa: E501

        Total tax on receipt  # noqa: E501

        :return: The total_tax of this Receipt.  # noqa: E501
        :rtype: float
        """
        return self._total_tax

    @total_tax.setter
    def total_tax(self, total_tax):
        """Sets the total_tax of this Receipt.

        Total tax on receipt  # noqa: E501

        :param total_tax: The total_tax of this Receipt.  # noqa: E501
        :type: float
        """

        self._total_tax = total_tax

    @property
    def total(self):
        """Gets the total of this Receipt.  # noqa: E501

        Total of receipt tax inclusive (i.e. SubTotal + TotalTax)  # noqa: E501

        :return: The total of this Receipt.  # noqa: E501
        :rtype: float
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this Receipt.

        Total of receipt tax inclusive (i.e. SubTotal + TotalTax)  # noqa: E501

        :param total: The total of this Receipt.  # noqa: E501
        :type: float
        """

        self._total = total

    @property
    def receipt_id(self):
        """Gets the receipt_id of this Receipt.  # noqa: E501

        Xero generated unique identifier for receipt  # noqa: E501

        :return: The receipt_id of this Receipt.  # noqa: E501
        :rtype: str
        """
        return self._receipt_id

    @receipt_id.setter
    def receipt_id(self, receipt_id):
        """Sets the receipt_id of this Receipt.

        Xero generated unique identifier for receipt  # noqa: E501

        :param receipt_id: The receipt_id of this Receipt.  # noqa: E501
        :type: str
        """

        self._receipt_id = receipt_id

    @property
    def status(self):
        """Gets the status of this Receipt.  # noqa: E501

        Current status of receipt – see status types  # noqa: E501

        :return: The status of this Receipt.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Receipt.

        Current status of receipt – see status types  # noqa: E501

        :param status: The status of this Receipt.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "DRAFT",
            "SUBMITTED",
            "AUTHORISED",
            "DECLINED",
            "VOIDED",
            "None",
        ]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status

    @property
    def receipt_number(self):
        """Gets the receipt_number of this Receipt.  # noqa: E501

        Xero generated sequence number for receipt in current claim for a given user  # noqa: E501

        :return: The receipt_number of this Receipt.  # noqa: E501
        :rtype: str
        """
        return self._receipt_number

    @receipt_number.setter
    def receipt_number(self, receipt_number):
        """Sets the receipt_number of this Receipt.

        Xero generated sequence number for receipt in current claim for a given user  # noqa: E501

        :param receipt_number: The receipt_number of this Receipt.  # noqa: E501
        :type: str
        """

        self._receipt_number = receipt_number

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this Receipt.  # noqa: E501

        Last modified date UTC format  # noqa: E501

        :return: The updated_date_utc of this Receipt.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this Receipt.

        Last modified date UTC format  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this Receipt.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def has_attachments(self):
        """Gets the has_attachments of this Receipt.  # noqa: E501

        boolean to indicate if a receipt has an attachment  # noqa: E501

        :return: The has_attachments of this Receipt.  # noqa: E501
        :rtype: bool
        """
        return self._has_attachments

    @has_attachments.setter
    def has_attachments(self, has_attachments):
        """Sets the has_attachments of this Receipt.

        boolean to indicate if a receipt has an attachment  # noqa: E501

        :param has_attachments: The has_attachments of this Receipt.  # noqa: E501
        :type: bool
        """

        self._has_attachments = has_attachments

    @property
    def url(self):
        """Gets the url of this Receipt.  # noqa: E501

        URL link to a source document – shown as “Go to [appName]” in the Xero app  # noqa: E501

        :return: The url of this Receipt.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Receipt.

        URL link to a source document – shown as “Go to [appName]” in the Xero app  # noqa: E501

        :param url: The url of this Receipt.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def validation_errors(self):
        """Gets the validation_errors of this Receipt.  # noqa: E501

        Displays array of validation error messages from the API  # noqa: E501

        :return: The validation_errors of this Receipt.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this Receipt.

        Displays array of validation error messages from the API  # noqa: E501

        :param validation_errors: The validation_errors of this Receipt.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors

    @property
    def warnings(self):
        """Gets the warnings of this Receipt.  # noqa: E501

        Displays array of warning messages from the API  # noqa: E501

        :return: The warnings of this Receipt.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this Receipt.

        Displays array of warning messages from the API  # noqa: E501

        :param warnings: The warnings of this Receipt.  # noqa: E501
        :type: list[ValidationError]
        """

        self._warnings = warnings

    @property
    def attachments(self):
        """Gets the attachments of this Receipt.  # noqa: E501

        Displays array of attachments from the API  # noqa: E501

        :return: The attachments of this Receipt.  # noqa: E501
        :rtype: list[Attachment]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """Sets the attachments of this Receipt.

        Displays array of attachments from the API  # noqa: E501

        :param attachments: The attachments of this Receipt.  # noqa: E501
        :type: list[Attachment]
        """

        self._attachments = attachments



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class ReportFields(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"field_id": "str", "description": "str", "value": "str"}

    attribute_map = {
        "field_id": "FieldID",
        "description": "Description",
        "value": "Value",
    }

    def __init__(self, field_id=None, description=None, value=None):  # noqa: E501
        """ReportFields - a model defined in OpenAPI"""  # noqa: E501

        self._field_id = None
        self._description = None
        self._value = None
        self.discriminator = None

        if field_id is not None:
            self.field_id = field_id
        if description is not None:
            self.description = description
        if value is not None:
            self.value = value

    @property
    def field_id(self):
        """Gets the field_id of this ReportFields.  # noqa: E501


        :return: The field_id of this ReportFields.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this ReportFields.


        :param field_id: The field_id of this ReportFields.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def description(self):
        """Gets the description of this ReportFields.  # noqa: E501


        :return: The description of this ReportFields.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ReportFields.


        :param description: The description of this ReportFields.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def value(self):
        """Gets the value of this ReportFields.  # noqa: E501


        :return: The value of this ReportFields.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ReportFields.


        :param value: The value of this ReportFields.  # noqa: E501
        :type: str
        """

        self._value = value



# coding: utf-8

# flake8: noqa

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


# import apis into sdk package
from xero_python.payrollnz.api.payroll_nz_api import PayrollNzApi


# import models into sdk package
from xero_python.payrollnz.models.account import Account
from xero_python.payrollnz.models.accounts import Accounts
from xero_python.payrollnz.models.address import Address
from xero_python.payrollnz.models.bank_account import BankAccount
from xero_python.payrollnz.models.benefit import Benefit
from xero_python.payrollnz.models.calendar_type import CalendarType
from xero_python.payrollnz.models.deduction import Deduction
from xero_python.payrollnz.models.deduction_line import DeductionLine
from xero_python.payrollnz.models.deduction_object import DeductionObject
from xero_python.payrollnz.models.deductions import Deductions
from xero_python.payrollnz.models.earnings_line import EarningsLine
from xero_python.payrollnz.models.earnings_order import EarningsOrder
from xero_python.payrollnz.models.earnings_order_object import EarningsOrderObject
from xero_python.payrollnz.models.earnings_orders import EarningsOrders
from xero_python.payrollnz.models.earnings_rate import EarningsRate
from xero_python.payrollnz.models.earnings_rate_object import EarningsRateObject
from xero_python.payrollnz.models.earnings_rates import EarningsRates
from xero_python.payrollnz.models.earnings_template import EarningsTemplate
from xero_python.payrollnz.models.earnings_template_object import EarningsTemplateObject
from xero_python.payrollnz.models.employee import Employee
from xero_python.payrollnz.models.employee_earnings_templates import (
    EmployeeEarningsTemplates,
)
from xero_python.payrollnz.models.employee_leave import EmployeeLeave
from xero_python.payrollnz.models.employee_leave_balance import EmployeeLeaveBalance
from xero_python.payrollnz.models.employee_leave_balances import EmployeeLeaveBalances
from xero_python.payrollnz.models.employee_leave_object import EmployeeLeaveObject
from xero_python.payrollnz.models.employee_leave_setup import EmployeeLeaveSetup
from xero_python.payrollnz.models.employee_leave_setup_object import (
    EmployeeLeaveSetupObject,
)
from xero_python.payrollnz.models.employee_leave_type import EmployeeLeaveType
from xero_python.payrollnz.models.employee_leave_type_object import (
    EmployeeLeaveTypeObject,
)
from xero_python.payrollnz.models.employee_leave_types import EmployeeLeaveTypes
from xero_python.payrollnz.models.employee_leaves import EmployeeLeaves
from xero_python.payrollnz.models.employee_object import EmployeeObject
from xero_python.payrollnz.models.employee_opening_balance import EmployeeOpeningBalance
from xero_python.payrollnz.models.employee_opening_balances_object import (
    EmployeeOpeningBalancesObject,
)
from xero_python.payrollnz.models.employee_pay_template import EmployeePayTemplate
from xero_python.payrollnz.models.employee_pay_template_object import (
    EmployeePayTemplateObject,
)
from xero_python.payrollnz.models.employee_pay_templates import EmployeePayTemplates
from xero_python.payrollnz.models.employee_statutory_leave_balance import (
    EmployeeStatutoryLeaveBalance,
)
from xero_python.payrollnz.models.employee_statutory_leave_balance_object import (
    EmployeeStatutoryLeaveBalanceObject,
)
from xero_python.payrollnz.models.employee_statutory_leave_summary import (
    EmployeeStatutoryLeaveSummary,
)
from xero_python.payrollnz.models.employee_statutory_leaves_summaries import (
    EmployeeStatutoryLeavesSummaries,
)
from xero_python.payrollnz.models.employee_statutory_sick_leave import (
    EmployeeStatutorySickLeave,
)
from xero_python.payrollnz.models.employee_statutory_sick_leave_object import (
    EmployeeStatutorySickLeaveObject,
)
from xero_python.payrollnz.models.employee_statutory_sick_leaves import (
    EmployeeStatutorySickLeaves,
)
from xero_python.payrollnz.models.employee_tax import EmployeeTax
from xero_python.payrollnz.models.employee_tax_object import EmployeeTaxObject
from xero_python.payrollnz.models.employees import Employees
from xero_python.payrollnz.models.employment import Employment
from xero_python.payrollnz.models.employment_object import EmploymentObject
from xero_python.payrollnz.models.gross_earnings_history import GrossEarningsHistory
from xero_python.payrollnz.models.invalid_field import InvalidField
from xero_python.payrollnz.models.leave_accrual_line import LeaveAccrualLine
from xero_python.payrollnz.models.leave_earnings_line import LeaveEarningsLine
from xero_python.payrollnz.models.leave_period import LeavePeriod
from xero_python.payrollnz.models.leave_periods import LeavePeriods
from xero_python.payrollnz.models.leave_type import LeaveType
from xero_python.payrollnz.models.leave_type_object import LeaveTypeObject
from xero_python.payrollnz.models.leave_types import LeaveTypes
from xero_python.payrollnz.models.pagination import Pagination
from xero_python.payrollnz.models.pay_run import PayRun
from xero_python.payrollnz.models.pay_run_calendar import PayRunCalendar
from xero_python.payrollnz.models.pay_run_calendar_object import PayRunCalendarObject
from xero_python.payrollnz.models.pay_run_calendars import PayRunCalendars
from xero_python.payrollnz.models.pay_run_object import PayRunObject
from xero_python.payrollnz.models.pay_runs import PayRuns
from xero_python.payrollnz.models.pay_slip import PaySlip
from xero_python.payrollnz.models.pay_slip_object import PaySlipObject
from xero_python.payrollnz.models.pay_slips import PaySlips
from xero_python.payrollnz.models.payment_line import PaymentLine
from xero_python.payrollnz.models.payment_method import PaymentMethod
from xero_python.payrollnz.models.payment_method_object import PaymentMethodObject
from xero_python.payrollnz.models.problem import Problem
from xero_python.payrollnz.models.reimbursement import Reimbursement
from xero_python.payrollnz.models.reimbursement_line import ReimbursementLine
from xero_python.payrollnz.models.reimbursement_object import ReimbursementObject
from xero_python.payrollnz.models.reimbursements import Reimbursements
from xero_python.payrollnz.models.salary_and_wage import SalaryAndWage
from xero_python.payrollnz.models.salary_and_wage_object import SalaryAndWageObject
from xero_python.payrollnz.models.salary_and_wages import SalaryAndWages
from xero_python.payrollnz.models.settings import Settings
from xero_python.payrollnz.models.statutory_deduction import StatutoryDeduction
from xero_python.payrollnz.models.statutory_deduction_category import (
    StatutoryDeductionCategory,
)
from xero_python.payrollnz.models.statutory_deduction_line import StatutoryDeductionLine
from xero_python.payrollnz.models.statutory_deduction_object import (
    StatutoryDeductionObject,
)
from xero_python.payrollnz.models.statutory_deductions import StatutoryDeductions
from xero_python.payrollnz.models.superannuation_line import SuperannuationLine
from xero_python.payrollnz.models.superannuation_object import SuperannuationObject
from xero_python.payrollnz.models.superannuations import Superannuations
from xero_python.payrollnz.models.tax_code import TaxCode
from xero_python.payrollnz.models.tax_line import TaxLine
from xero_python.payrollnz.models.tax_settings import TaxSettings
from xero_python.payrollnz.models.timesheet import Timesheet
from xero_python.payrollnz.models.timesheet_earnings_line import TimesheetEarningsLine
from xero_python.payrollnz.models.timesheet_line import TimesheetLine
from xero_python.payrollnz.models.timesheet_line_object import TimesheetLineObject
from xero_python.payrollnz.models.timesheet_object import TimesheetObject
from xero_python.payrollnz.models.timesheets import Timesheets
from xero_python.payrollnz.models.tracking_categories import TrackingCategories
from xero_python.payrollnz.models.tracking_category import TrackingCategory



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class ExternalLink(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"link_type": "str", "url": "str", "description": "str"}

    attribute_map = {
        "link_type": "LinkType",
        "url": "Url",
        "description": "Description",
    }

    def __init__(self, link_type=None, url=None, description=None):  # noqa: E501
        """ExternalLink - a model defined in OpenAPI"""  # noqa: E501

        self._link_type = None
        self._url = None
        self._description = None
        self.discriminator = None

        if link_type is not None:
            self.link_type = link_type
        if url is not None:
            self.url = url
        if description is not None:
            self.description = description

    @property
    def link_type(self):
        """Gets the link_type of this ExternalLink.  # noqa: E501

        See External link types  # noqa: E501

        :return: The link_type of this ExternalLink.  # noqa: E501
        :rtype: str
        """
        return self._link_type

    @link_type.setter
    def link_type(self, link_type):
        """Sets the link_type of this ExternalLink.

        See External link types  # noqa: E501

        :param link_type: The link_type of this ExternalLink.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "Facebook",
            "GooglePlus",
            "LinkedIn",
            "Twitter",
            "Website",
            "None",
        ]  # noqa: E501

        if link_type:
            if link_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `link_type` ({0}), must be one of {1}".format(  # noqa: E501
                        link_type, allowed_values
                    )
                )

        self._link_type = link_type

    @property
    def url(self):
        """Gets the url of this ExternalLink.  # noqa: E501

        URL for service e.g. http://twitter.com/xeroapi  # noqa: E501

        :return: The url of this ExternalLink.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this ExternalLink.

        URL for service e.g. http://twitter.com/xeroapi  # noqa: E501

        :param url: The url of this ExternalLink.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def description(self):
        """Gets the description of this ExternalLink.  # noqa: E501


        :return: The description of this ExternalLink.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ExternalLink.


        :param description: The description of this ExternalLink.  # noqa: E501
        :type: str
        """

        self._description = description



# coding: utf-8

"""
    Xero Projects API

    This is the Xero Projects API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class ProjectUser(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"user_id": "str", "name": "str", "email": "str"}

    attribute_map = {"user_id": "userId", "name": "name", "email": "email"}

    def __init__(self, user_id=None, name=None, email=None):  # noqa: E501
        """ProjectUser - a model defined in OpenAPI"""  # noqa: E501

        self._user_id = None
        self._name = None
        self._email = None
        self.discriminator = None

        if user_id is not None:
            self.user_id = user_id
        if name is not None:
            self.name = name
        if email is not None:
            self.email = email

    @property
    def user_id(self):
        """Gets the user_id of this ProjectUser.  # noqa: E501

        Identifier of the user of the project.  # noqa: E501

        :return: The user_id of this ProjectUser.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ProjectUser.

        Identifier of the user of the project.  # noqa: E501

        :param user_id: The user_id of this ProjectUser.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def name(self):
        """Gets the name of this ProjectUser.  # noqa: E501

        Full name of the user.  # noqa: E501

        :return: The name of this ProjectUser.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProjectUser.

        Full name of the user.  # noqa: E501

        :param name: The name of this ProjectUser.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def email(self):
        """Gets the email of this ProjectUser.  # noqa: E501

        Email address of the user.  # noqa: E501

        :return: The email of this ProjectUser.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ProjectUser.

        Email address of the user.  # noqa: E501

        :param email: The email of this ProjectUser.  # noqa: E501
        :type: str
        """

        self._email = email



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class TrackingCategory(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "tracking_category_id": "str",
        "tracking_option_id": "str",
        "name": "str",
        "option": "str",
        "status": "str",
        "options": "list[TrackingOption]",
    }

    attribute_map = {
        "tracking_category_id": "TrackingCategoryID",
        "tracking_option_id": "TrackingOptionID",
        "name": "Name",
        "option": "Option",
        "status": "Status",
        "options": "Options",
    }

    def __init__(
        self,
        tracking_category_id=None,
        tracking_option_id=None,
        name=None,
        option=None,
        status=None,
        options=None,
    ):  # noqa: E501
        """TrackingCategory - a model defined in OpenAPI"""  # noqa: E501

        self._tracking_category_id = None
        self._tracking_option_id = None
        self._name = None
        self._option = None
        self._status = None
        self._options = None
        self.discriminator = None

        if tracking_category_id is not None:
            self.tracking_category_id = tracking_category_id
        if tracking_option_id is not None:
            self.tracking_option_id = tracking_option_id
        if name is not None:
            self.name = name
        if option is not None:
            self.option = option
        if status is not None:
            self.status = status
        if options is not None:
            self.options = options

    @property
    def tracking_category_id(self):
        """Gets the tracking_category_id of this TrackingCategory.  # noqa: E501

        The Xero identifier for a tracking category e.g. 297c2dc5-cc47-4afd-8ec8-74990b8761e9  # noqa: E501

        :return: The tracking_category_id of this TrackingCategory.  # noqa: E501
        :rtype: str
        """
        return self._tracking_category_id

    @tracking_category_id.setter
    def tracking_category_id(self, tracking_category_id):
        """Sets the tracking_category_id of this TrackingCategory.

        The Xero identifier for a tracking category e.g. 297c2dc5-cc47-4afd-8ec8-74990b8761e9  # noqa: E501

        :param tracking_category_id: The tracking_category_id of this TrackingCategory.  # noqa: E501
        :type: str
        """

        self._tracking_category_id = tracking_category_id

    @property
    def tracking_option_id(self):
        """Gets the tracking_option_id of this TrackingCategory.  # noqa: E501

        The Xero identifier for a tracking option e.g. dc54c220-0140-495a-b925-3246adc0075f  # noqa: E501

        :return: The tracking_option_id of this TrackingCategory.  # noqa: E501
        :rtype: str
        """
        return self._tracking_option_id

    @tracking_option_id.setter
    def tracking_option_id(self, tracking_option_id):
        """Sets the tracking_option_id of this TrackingCategory.

        The Xero identifier for a tracking option e.g. dc54c220-0140-495a-b925-3246adc0075f  # noqa: E501

        :param tracking_option_id: The tracking_option_id of this TrackingCategory.  # noqa: E501
        :type: str
        """

        self._tracking_option_id = tracking_option_id

    @property
    def name(self):
        """Gets the name of this TrackingCategory.  # noqa: E501

        The name of the tracking category e.g. Department, Region (max length = 100)  # noqa: E501

        :return: The name of this TrackingCategory.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TrackingCategory.

        The name of the tracking category e.g. Department, Region (max length = 100)  # noqa: E501

        :param name: The name of this TrackingCategory.  # noqa: E501
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError(
                "Invalid value for `name`, "
                "length must be less than or equal to `100`"
            )  # noqa: E501

        self._name = name

    @property
    def option(self):
        """Gets the option of this TrackingCategory.  # noqa: E501

        The option name of the tracking option e.g. East, West (max length = 100)  # noqa: E501

        :return: The option of this TrackingCategory.  # noqa: E501
        :rtype: str
        """
        return self._option

    @option.setter
    def option(self, option):
        """Sets the option of this TrackingCategory.

        The option name of the tracking option e.g. East, West (max length = 100)  # noqa: E501

        :param option: The option of this TrackingCategory.  # noqa: E501
        :type: str
        """
        if option is not None and len(option) > 100:
            raise ValueError(
                "Invalid value for `option`, "
                "length must be less than or equal to `100`"
            )  # noqa: E501

        self._option = option

    @property
    def status(self):
        """Gets the status of this TrackingCategory.  # noqa: E501

        The status of a tracking category  # noqa: E501

        :return: The status of this TrackingCategory.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this TrackingCategory.

        The status of a tracking category  # noqa: E501

        :param status: The status of this TrackingCategory.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACTIVE", "ARCHIVED", "DELETED", "None"]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status

    @property
    def options(self):
        """Gets the options of this TrackingCategory.  # noqa: E501

        See Tracking Options  # noqa: E501

        :return: The options of this TrackingCategory.  # noqa: E501
        :rtype: list[TrackingOption]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this TrackingCategory.

        See Tracking Options  # noqa: E501

        :param options: The options of this TrackingCategory.  # noqa: E501
        :type: list[TrackingOption]
        """

        self._options = options



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""

"""
    OpenAPI spec version: 2.10.4
"""

import importlib
import re  # noqa: F401

from xero_python import exceptions
from xero_python.api_client import ApiClient, ModelFinder

try:
    from .exception_handler import translate_status_exception
except ImportError:
    translate_status_exception = exceptions.translate_status_exception


class empty:
    """ empty object to mark optional parameter not set """


class PayrollAuApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    base_url = "https://api.xero.com/payroll.xro/1.0"
    models_module = importlib.import_module("xero_python.payrollau.models")

    def __init__(self, api_client=None, base_url=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.base_url = base_url or self.base_url

    def get_resource_url(self, resource_path):
        """
        Combine API base url with resource specific path
        :param str resource_path: API endpoint specific path
        :return: str full resource path
        """
        return self.base_url + resource_path

    def get_model_finder(self):
        return ModelFinder(self.models_module)

    def create_employee(
        self,
        xero_tenant_id,
        employee,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Creates a payroll employee  # noqa: E501
        OAuth2 scope: payroll.employees
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param list[Employee] employee: (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Employees
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `create_employee`"
            )
        # verify the required parameter 'employee' is set
        if employee is None:
            raise ValueError(
                "Missing the required parameter `employee` "
                "when calling `create_employee`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = employee
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Employees")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Employees",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "create_employee")

    def create_leave_application(
        self,
        xero_tenant_id,
        leave_application,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Creates a leave application  # noqa: E501
        OAuth2 scope: payroll.leaveapplications
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param list[LeaveApplication] leave_application: (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: LeaveApplications
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `create_leave_application`"
            )
        # verify the required parameter 'leave_application' is set
        if leave_application is None:
            raise ValueError(
                "Missing the required parameter `leave_application` "
                "when calling `create_leave_application`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = leave_application
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/LeaveApplications")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="LeaveApplications",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "create_leave_application")

    def create_pay_item(
        self,
        xero_tenant_id,
        pay_item,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Creates a pay item  # noqa: E501
        OAuth2 scope: payroll.payitems
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param PayItem pay_item: (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: PayItems
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `create_pay_item`"
            )
        # verify the required parameter 'pay_item' is set
        if pay_item is None:
            raise ValueError(
                "Missing the required parameter `pay_item` "
                "when calling `create_pay_item`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = pay_item
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/PayItems")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="PayItems",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "create_pay_item")

    def create_pay_run(
        self,
        xero_tenant_id,
        pay_run,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Creates a pay run  # noqa: E501
        OAuth2 scope: payroll.payruns
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param list[PayRun] pay_run: (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: PayRuns
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `create_pay_run`"
            )
        # verify the required parameter 'pay_run' is set
        if pay_run is None:
            raise ValueError(
                "Missing the required parameter `pay_run` "
                "when calling `create_pay_run`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = pay_run
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/PayRuns")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="PayRuns",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "create_pay_run")

    def create_payroll_calendar(
        self,
        xero_tenant_id,
        payroll_calendar,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Creates a Payroll Calendar  # noqa: E501
        OAuth2 scope: payroll.payrollcalendars
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param list[PayrollCalendar] payroll_calendar: (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: PayrollCalendars
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `create_payroll_calendar`"
            )
        # verify the required parameter 'payroll_calendar' is set
        if payroll_calendar is None:
            raise ValueError(
                "Missing the required parameter `payroll_calendar` "
                "when calling `create_payroll_calendar`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = payroll_calendar
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/PayrollCalendars")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="PayrollCalendars",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "create_payroll_calendar")

    def create_superfund(
        self,
        xero_tenant_id,
        super_fund,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Creates a superfund  # noqa: E501
        OAuth2 scope: payroll.superfunds
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param list[SuperFund] super_fund: (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: SuperFunds
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `create_superfund`"
            )
        # verify the required parameter 'super_fund' is set
        if super_fund is None:
            raise ValueError(
                "Missing the required parameter `super_fund` "
                "when calling `create_superfund`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = super_fund
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Superfunds")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="SuperFunds",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "create_superfund")

    def create_timesheet(
        self,
        xero_tenant_id,
        timesheet,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Creates a timesheet  # noqa: E501
        OAuth2 scope: payroll.timesheets
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param list[Timesheet] timesheet: (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Timesheets
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `create_timesheet`"
            )
        # verify the required parameter 'timesheet' is set
        if timesheet is None:
            raise ValueError(
                "Missing the required parameter `timesheet` "
                "when calling `create_timesheet`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = timesheet
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Timesheets")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Timesheets",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "create_timesheet")

    def get_employee(
        self,
        xero_tenant_id,
        employee_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves an employee's detail by unique employee id  # noqa: E501
        OAuth2 scope: payroll.employees.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str employee_id: Employee id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Employees
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_employee`"
            )
        # verify the required parameter 'employee_id' is set
        if employee_id is None:
            raise ValueError(
                "Missing the required parameter `employee_id` "
                "when calling `get_employee`"
            )

        collection_formats = {}
        path_params = {
            "EmployeeID": employee_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Employees/{EmployeeID}")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Employees",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_employee")

    def get_employees(
        self,
        xero_tenant_id,
        if_modified_since=empty,
        where=empty,
        order=empty,
        page=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Searches payroll employees  # noqa: E501
        OAuth2 scope: payroll.employees.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str if_modified_since: Only records created or modified since this timestamp will be returned
        :param str where: Filter by an any element
        :param str order: Order by an any element
        :param int page: e.g. page=1 – Up to 100 employees will be returned in a single API call
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Employees
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_employees`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        if where is not empty:
            query_params.append(("where", where))

        if order is not empty:
            query_params.append(("order", order))

        if page is not empty:
            query_params.append(("page", page))

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        if if_modified_since is not empty:
            header_params["If-Modified-Since"] = if_modified_since

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Employees")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Employees",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_employees")

    def get_leave_application(
        self,
        xero_tenant_id,
        leave_application_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves a leave application by a unique leave application id  # noqa: E501
        OAuth2 scope: payroll.leaveapplications.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str leave_application_id: Leave Application id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: LeaveApplications
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_leave_application`"
            )
        # verify the required parameter 'leave_application_id' is set
        if leave_application_id is None:
            raise ValueError(
                "Missing the required parameter `leave_application_id` "
                "when calling `get_leave_application`"
            )

        collection_formats = {}
        path_params = {
            "LeaveApplicationID": leave_application_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/LeaveApplications/{LeaveApplicationID}")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="LeaveApplications",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_leave_application")

    def get_leave_applications(
        self,
        xero_tenant_id,
        if_modified_since=empty,
        where=empty,
        order=empty,
        page=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves leave applications  # noqa: E501
        OAuth2 scope: payroll.leaveapplications.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str if_modified_since: Only records created or modified since this timestamp will be returned
        :param str where: Filter by an any element
        :param str order: Order by an any element
        :param int page: e.g. page=1 – Up to 100 objects will be returned in a single API call
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: LeaveApplications
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_leave_applications`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        if where is not empty:
            query_params.append(("where", where))

        if order is not empty:
            query_params.append(("order", order))

        if page is not empty:
            query_params.append(("page", page))

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        if if_modified_since is not empty:
            header_params["If-Modified-Since"] = if_modified_since

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/LeaveApplications")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="LeaveApplications",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_leave_applications")

    def get_pay_items(
        self,
        xero_tenant_id,
        if_modified_since=empty,
        where=empty,
        order=empty,
        page=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves pay items  # noqa: E501
        OAuth2 scope: payroll.payitems.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str if_modified_since: Only records created or modified since this timestamp will be returned
        :param str where: Filter by an any element
        :param str order: Order by an any element
        :param int page: e.g. page=1 – Up to 100 objects will be returned in a single API call
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: PayItems
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_pay_items`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        if where is not empty:
            query_params.append(("where", where))

        if order is not empty:
            query_params.append(("order", order))

        if page is not empty:
            query_params.append(("page", page))

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        if if_modified_since is not empty:
            header_params["If-Modified-Since"] = if_modified_since

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/PayItems")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="PayItems",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_pay_items")

    def get_pay_run(
        self,
        xero_tenant_id,
        pay_run_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves a pay run by using a unique pay run id  # noqa: E501
        OAuth2 scope: payroll.payruns.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str pay_run_id: PayRun id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: PayRuns
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_pay_run`"
            )
        # verify the required parameter 'pay_run_id' is set
        if pay_run_id is None:
            raise ValueError(
                "Missing the required parameter `pay_run_id` "
                "when calling `get_pay_run`"
            )

        collection_formats = {}
        path_params = {
            "PayRunID": pay_run_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/PayRuns/{PayRunID}")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="PayRuns",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_pay_run")

    def get_pay_runs(
        self,
        xero_tenant_id,
        if_modified_since=empty,
        where=empty,
        order=empty,
        page=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves pay runs  # noqa: E501
        OAuth2 scope: payroll.payruns.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str if_modified_since: Only records created or modified since this timestamp will be returned
        :param str where: Filter by an any element
        :param str order: Order by an any element
        :param int page: e.g. page=1 – Up to 100 PayRuns will be returned in a single API call
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: PayRuns
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_pay_runs`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        if where is not empty:
            query_params.append(("where", where))

        if order is not empty:
            query_params.append(("order", order))

        if page is not empty:
            query_params.append(("page", page))

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        if if_modified_since is not empty:
            header_params["If-Modified-Since"] = if_modified_since

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/PayRuns")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="PayRuns",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_pay_runs")

    def get_payroll_calendar(
        self,
        xero_tenant_id,
        payroll_calendar_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves payroll calendar by using a unique payroll calendar ID  # noqa: E501
        OAuth2 scope: payroll.payrollcalendars.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str payroll_calendar_id: Payroll Calendar id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: PayrollCalendars
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_payroll_calendar`"
            )
        # verify the required parameter 'payroll_calendar_id' is set
        if payroll_calendar_id is None:
            raise ValueError(
                "Missing the required parameter `payroll_calendar_id` "
                "when calling `get_payroll_calendar`"
            )

        collection_formats = {}
        path_params = {
            "PayrollCalendarID": payroll_calendar_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/PayrollCalendars/{PayrollCalendarID}")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="PayrollCalendars",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_payroll_calendar")

    def get_payroll_calendars(
        self,
        xero_tenant_id,
        if_modified_since=empty,
        where=empty,
        order=empty,
        page=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves payroll calendars  # noqa: E501
        OAuth2 scope: payroll.payrollcalendars.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str if_modified_since: Only records created or modified since this timestamp will be returned
        :param str where: Filter by an any element
        :param str order: Order by an any element
        :param int page: e.g. page=1 – Up to 100 objects will be returned in a single API call
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: PayrollCalendars
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_payroll_calendars`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        if where is not empty:
            query_params.append(("where", where))

        if order is not empty:
            query_params.append(("order", order))

        if page is not empty:
            query_params.append(("page", page))

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        if if_modified_since is not empty:
            header_params["If-Modified-Since"] = if_modified_since

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/PayrollCalendars")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="PayrollCalendars",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_payroll_calendars")

    def get_payslip(
        self,
        xero_tenant_id,
        payslip_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves for a payslip by a unique payslip id  # noqa: E501
        OAuth2 scope: payroll.payslip.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str payslip_id: Payslip id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: PayslipObject
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_payslip`"
            )
        # verify the required parameter 'payslip_id' is set
        if payslip_id is None:
            raise ValueError(
                "Missing the required parameter `payslip_id` "
                "when calling `get_payslip`"
            )

        collection_formats = {}
        path_params = {
            "PayslipID": payslip_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Payslip/{PayslipID}")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="PayslipObject",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_payslip")

    def get_settings(
        self,
        xero_tenant_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves payroll settings  # noqa: E501
        OAuth2 scope: payroll.settings.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: SettingsObject
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_settings`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Settings")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="SettingsObject",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_settings")

    def get_superfund(
        self,
        xero_tenant_id,
        super_fund_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves a superfund by using a unique superfund ID  # noqa: E501
        OAuth2 scope: payroll.superfunds.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str super_fund_id: Superfund id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: SuperFunds
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_superfund`"
            )
        # verify the required parameter 'super_fund_id' is set
        if super_fund_id is None:
            raise ValueError(
                "Missing the required parameter `super_fund_id` "
                "when calling `get_superfund`"
            )

        collection_formats = {}
        path_params = {
            "SuperFundID": super_fund_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Superfunds/{SuperFundID}")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="SuperFunds",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_superfund")

    def get_superfund_products(
        self,
        xero_tenant_id,
        abn=empty,
        usi=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves superfund products  # noqa: E501
        OAuth2 scope: payroll.superfundproducts.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str abn: The ABN of the Regulated SuperFund
        :param str usi: The USI of the Regulated SuperFund
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: SuperFundProducts
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_superfund_products`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        if abn is not empty:
            query_params.append(("ABN", abn))

        if usi is not empty:
            query_params.append(("USI", usi))

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/SuperfundProducts")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="SuperFundProducts",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_superfund_products")

    def get_superfunds(
        self,
        xero_tenant_id,
        if_modified_since=empty,
        where=empty,
        order=empty,
        page=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves superfunds  # noqa: E501
        OAuth2 scope: payroll.superfunds.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str if_modified_since: Only records created or modified since this timestamp will be returned
        :param str where: Filter by an any element
        :param str order: Order by an any element
        :param int page: e.g. page=1 – Up to 100 SuperFunds will be returned in a single API call
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: SuperFunds
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_superfunds`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        if where is not empty:
            query_params.append(("where", where))

        if order is not empty:
            query_params.append(("order", order))

        if page is not empty:
            query_params.append(("page", page))

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        if if_modified_since is not empty:
            header_params["If-Modified-Since"] = if_modified_since

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Superfunds")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="SuperFunds",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_superfunds")

    def get_timesheet(
        self,
        xero_tenant_id,
        timesheet_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves a timesheet by using a unique timesheet id  # noqa: E501
        OAuth2 scope: payroll.timesheets.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str timesheet_id: Timesheet id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: TimesheetObject
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_timesheet`"
            )
        # verify the required parameter 'timesheet_id' is set
        if timesheet_id is None:
            raise ValueError(
                "Missing the required parameter `timesheet_id` "
                "when calling `get_timesheet`"
            )

        collection_formats = {}
        path_params = {
            "TimesheetID": timesheet_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Timesheets/{TimesheetID}")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="TimesheetObject",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_timesheet")

    def get_timesheets(
        self,
        xero_tenant_id,
        if_modified_since=empty,
        where=empty,
        order=empty,
        page=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves timesheets  # noqa: E501
        OAuth2 scope: payroll.timesheets.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str if_modified_since: Only records created or modified since this timestamp will be returned
        :param str where: Filter by an any element
        :param str order: Order by an any element
        :param int page: e.g. page=1 – Up to 100 timesheets will be returned in a single API call
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Timesheets
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_timesheets`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        if where is not empty:
            query_params.append(("where", where))

        if order is not empty:
            query_params.append(("order", order))

        if page is not empty:
            query_params.append(("page", page))

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        if if_modified_since is not empty:
            header_params["If-Modified-Since"] = if_modified_since

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Timesheets")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Timesheets",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_timesheets")

    def update_employee(
        self,
        xero_tenant_id,
        employee_id,
        employee=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Updates an employee's detail  # noqa: E501
        OAuth2 scope: payroll.employees
        Update properties on a single employee  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str employee_id: Employee id for single object (required)
        :param list[Employee] employee:
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Employees
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `update_employee`"
            )
        # verify the required parameter 'employee_id' is set
        if employee_id is None:
            raise ValueError(
                "Missing the required parameter `employee_id` "
                "when calling `update_employee`"
            )

        collection_formats = {}
        path_params = {
            "EmployeeID": employee_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = employee
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Employees/{EmployeeID}")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Employees",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "update_employee")

    def update_leave_application(
        self,
        xero_tenant_id,
        leave_application_id,
        leave_application,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Updates a specific leave application  # noqa: E501
        OAuth2 scope: payroll.leaveapplications
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str leave_application_id: Leave Application id for single object (required)
        :param list[LeaveApplication] leave_application: (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: LeaveApplications
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `update_leave_application`"
            )
        # verify the required parameter 'leave_application_id' is set
        if leave_application_id is None:
            raise ValueError(
                "Missing the required parameter `leave_application_id` "
                "when calling `update_leave_application`"
            )
        # verify the required parameter 'leave_application' is set
        if leave_application is None:
            raise ValueError(
                "Missing the required parameter `leave_application` "
                "when calling `update_leave_application`"
            )

        collection_formats = {}
        path_params = {
            "LeaveApplicationID": leave_application_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = leave_application
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/LeaveApplications/{LeaveApplicationID}")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="LeaveApplications",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "update_leave_application")

    def update_pay_run(
        self,
        xero_tenant_id,
        pay_run_id,
        pay_run=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Updates a pay run  # noqa: E501
        OAuth2 scope: payroll.payruns
        Update properties on a single PayRun  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str pay_run_id: PayRun id for single object (required)
        :param list[PayRun] pay_run:
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: PayRuns
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `update_pay_run`"
            )
        # verify the required parameter 'pay_run_id' is set
        if pay_run_id is None:
            raise ValueError(
                "Missing the required parameter `pay_run_id` "
                "when calling `update_pay_run`"
            )

        collection_formats = {}
        path_params = {
            "PayRunID": pay_run_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = pay_run
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/PayRuns/{PayRunID}")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="PayRuns",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "update_pay_run")

    def update_payslip(
        self,
        xero_tenant_id,
        payslip_id,
        payslip_lines=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Updates a payslip  # noqa: E501
        OAuth2 scope: payroll.payslip
        Update lines on a single payslips  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str payslip_id: Payslip id for single object (required)
        :param list[PayslipLines] payslip_lines:
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Payslips
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `update_payslip`"
            )
        # verify the required parameter 'payslip_id' is set
        if payslip_id is None:
            raise ValueError(
                "Missing the required parameter `payslip_id` "
                "when calling `update_payslip`"
            )

        collection_formats = {}
        path_params = {
            "PayslipID": payslip_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = payslip_lines
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Payslip/{PayslipID}")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Payslips",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "update_payslip")

    def update_superfund(
        self,
        xero_tenant_id,
        super_fund_id,
        super_fund=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Updates a superfund  # noqa: E501
        OAuth2 scope: payroll.superfunds
        Update properties on a single Superfund  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str super_fund_id: Superfund id for single object (required)
        :param list[SuperFund] super_fund:
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: SuperFunds
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `update_superfund`"
            )
        # verify the required parameter 'super_fund_id' is set
        if super_fund_id is None:
            raise ValueError(
                "Missing the required parameter `super_fund_id` "
                "when calling `update_superfund`"
            )

        collection_formats = {}
        path_params = {
            "SuperFundID": super_fund_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = super_fund
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Superfunds/{SuperFundID}")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="SuperFunds",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "update_superfund")

    def update_timesheet(
        self,
        xero_tenant_id,
        timesheet_id,
        timesheet=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Updates a timesheet  # noqa: E501
        OAuth2 scope: payroll.timesheets
        Update properties on a single timesheet  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str timesheet_id: Timesheet id for single object (required)
        :param list[Timesheet] timesheet:
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Timesheets
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `update_timesheet`"
            )
        # verify the required parameter 'timesheet_id' is set
        if timesheet_id is None:
            raise ValueError(
                "Missing the required parameter `timesheet_id` "
                "when calling `update_timesheet`"
            )

        collection_formats = {}
        path_params = {
            "TimesheetID": timesheet_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = timesheet
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Timesheets/{TimesheetID}")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Timesheets",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "update_timesheet")



# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class TaxSettings(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "period_units": "float",
        "period_type": "str",
        "tax_code": "TaxCode",
        "special_tax_rate": "str",
        "lump_sum_tax_code": "str",
        "lump_sum_amount": "str",
    }

    attribute_map = {
        "period_units": "periodUnits",
        "period_type": "periodType",
        "tax_code": "taxCode",
        "special_tax_rate": "specialTaxRate",
        "lump_sum_tax_code": "lumpSumTaxCode",
        "lump_sum_amount": "lumpSumAmount",
    }

    def __init__(
        self,
        period_units=None,
        period_type=None,
        tax_code=None,
        special_tax_rate=None,
        lump_sum_tax_code=None,
        lump_sum_amount=None,
    ):  # noqa: E501
        """TaxSettings - a model defined in OpenAPI"""  # noqa: E501

        self._period_units = None
        self._period_type = None
        self._tax_code = None
        self._special_tax_rate = None
        self._lump_sum_tax_code = None
        self._lump_sum_amount = None
        self.discriminator = None

        if period_units is not None:
            self.period_units = period_units
        if period_type is not None:
            self.period_type = period_type
        if tax_code is not None:
            self.tax_code = tax_code
        if special_tax_rate is not None:
            self.special_tax_rate = special_tax_rate
        if lump_sum_tax_code is not None:
            self.lump_sum_tax_code = lump_sum_tax_code
        if lump_sum_amount is not None:
            self.lump_sum_amount = lump_sum_amount

    @property
    def period_units(self):
        """Gets the period_units of this TaxSettings.  # noqa: E501

        The number of units for the period type  # noqa: E501

        :return: The period_units of this TaxSettings.  # noqa: E501
        :rtype: float
        """
        return self._period_units

    @period_units.setter
    def period_units(self, period_units):
        """Sets the period_units of this TaxSettings.

        The number of units for the period type  # noqa: E501

        :param period_units: The period_units of this TaxSettings.  # noqa: E501
        :type: float
        """

        self._period_units = period_units

    @property
    def period_type(self):
        """Gets the period_type of this TaxSettings.  # noqa: E501

        The type of period (\"weeks\" or \"months\")  # noqa: E501

        :return: The period_type of this TaxSettings.  # noqa: E501
        :rtype: str
        """
        return self._period_type

    @period_type.setter
    def period_type(self, period_type):
        """Sets the period_type of this TaxSettings.

        The type of period (\"weeks\" or \"months\")  # noqa: E501

        :param period_type: The period_type of this TaxSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["weeks", "months", "None"]  # noqa: E501

        if period_type:
            if period_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `period_type` ({0}), must be one of {1}".format(  # noqa: E501
                        period_type, allowed_values
                    )
                )

        self._period_type = period_type

    @property
    def tax_code(self):
        """Gets the tax_code of this TaxSettings.  # noqa: E501


        :return: The tax_code of this TaxSettings.  # noqa: E501
        :rtype: TaxCode
        """
        return self._tax_code

    @tax_code.setter
    def tax_code(self, tax_code):
        """Sets the tax_code of this TaxSettings.


        :param tax_code: The tax_code of this TaxSettings.  # noqa: E501
        :type: TaxCode
        """

        self._tax_code = tax_code

    @property
    def special_tax_rate(self):
        """Gets the special_tax_rate of this TaxSettings.  # noqa: E501

        Tax rate for STC and WT  # noqa: E501

        :return: The special_tax_rate of this TaxSettings.  # noqa: E501
        :rtype: str
        """
        return self._special_tax_rate

    @special_tax_rate.setter
    def special_tax_rate(self, special_tax_rate):
        """Sets the special_tax_rate of this TaxSettings.

        Tax rate for STC and WT  # noqa: E501

        :param special_tax_rate: The special_tax_rate of this TaxSettings.  # noqa: E501
        :type: str
        """

        self._special_tax_rate = special_tax_rate

    @property
    def lump_sum_tax_code(self):
        """Gets the lump_sum_tax_code of this TaxSettings.  # noqa: E501

        Tax code for a lump sum amount  # noqa: E501

        :return: The lump_sum_tax_code of this TaxSettings.  # noqa: E501
        :rtype: str
        """
        return self._lump_sum_tax_code

    @lump_sum_tax_code.setter
    def lump_sum_tax_code(self, lump_sum_tax_code):
        """Sets the lump_sum_tax_code of this TaxSettings.

        Tax code for a lump sum amount  # noqa: E501

        :param lump_sum_tax_code: The lump_sum_tax_code of this TaxSettings.  # noqa: E501
        :type: str
        """

        self._lump_sum_tax_code = lump_sum_tax_code

    @property
    def lump_sum_amount(self):
        """Gets the lump_sum_amount of this TaxSettings.  # noqa: E501

        The total of the lump sum amount  # noqa: E501

        :return: The lump_sum_amount of this TaxSettings.  # noqa: E501
        :rtype: str
        """
        return self._lump_sum_amount

    @lump_sum_amount.setter
    def lump_sum_amount(self, lump_sum_amount):
        """Sets the lump_sum_amount of this TaxSettings.

        The total of the lump sum amount  # noqa: E501

        :param lump_sum_amount: The lump_sum_amount of this TaxSettings.  # noqa: E501
        :type: str
        """

        self._lump_sum_amount = lump_sum_amount



# -*- coding: utf-8 -*-
import datetime
import time

import pytest

from tests import FakeMethod, FakeClass
from tests.conftest import get_token_value
from xero_python.api_client import ApiClient
from xero_python.api_client.configuration import Configuration
from xero_python.api_client.oauth2 import TokenApi, OAuth2Token
from xero_python.exceptions import AccessTokenExpiredError


# from os.path import join, dirname


def test_access_token_configuration(oauth2_token):
    # given oauth2_token is oauthlib token dictionary
    assert isinstance(oauth2_token, dict)
    token = OAuth2Token()
    # When updating OAuth2Token configuration
    token.update_token(**oauth2_token)
    # Then expect token configuration created
    assert token.access_token == oauth2_token["access_token"]


class FakeOAuth2Token:
    def __init__(self, value):
        self.value = value

    def get_auth_settings(self):
        return self.value


def test_configuration_uses_oauth2_token():
    # Given properly configured ApiClient
    result = "auth configuration"
    configuration = Configuration()
    configuration.oauth2_token = FakeOAuth2Token(result)
    # When auth_settings settings created
    auth_settings = configuration.auth_settings("OAuth2")
    # Then auth_settings correct value
    assert auth_settings is result


def test_auth2_token_is_valid():
    # Given valid token
    expires_at = time.time() + 3
    oauth2_token = OAuth2Token(expiration_buffer=0)
    oauth2_token.expires_at = expires_at
    # Then check token is currently valid
    assert oauth2_token.is_access_token_valid()
    # and it will be valid at specific time
    assert oauth2_token.is_access_token_valid(at_time=expires_at - 1)


def test_auth2_token_is_invalid_expiration_buffer():
    # Given valid token
    expires_at = time.time() + OAuth2Token.EXPIRATION_BUFFER_DEFAULT - 1
    oauth2_token = OAuth2Token()
    oauth2_token.expires_at = expires_at
    # Then check token is currently invalid (expiration buffer applied)
    assert not oauth2_token.is_access_token_valid()
    # and it will be valid at specific time (expiration buffer not applied)
    assert oauth2_token.is_access_token_valid(at_time=expires_at - 1)


def test_auth2_token_is_valid_indefinitely():
    # Given indefinitely valid token
    far_future = datetime.datetime.today() + datetime.timedelta(days=365)
    oauth2_token = OAuth2Token()
    # Then check token is currently valid
    assert oauth2_token.is_access_token_valid()
    # and it will be valid in far future
    assert oauth2_token.is_access_token_valid(at_time=far_future.timestamp())


def test_auth2_get_valid_token():
    # given OAuth2Token with valid access_token
    token = "access token value"
    oauth2_token = OAuth2Token()
    oauth2_token.access_token = token
    # Then correct access token value expected
    assert oauth2_token.get_valid_access_token() == token


def test_auth2_get_invalid_token():
    # given OAuth2Token with invalid access_token
    token = "access token value"
    expires_at = time.time() - 4
    oauth2_token = OAuth2Token()
    oauth2_token.access_token = token
    oauth2_token.expires_at = expires_at
    # Then correct access token value expected
    with pytest.raises(AccessTokenExpiredError):
        oauth2_token.get_valid_access_token()
    with pytest.raises(AccessTokenExpiredError):
        oauth2_token.get_valid_access_token(at_time=expires_at + 1)


def test_auth2_refresh_access_token():
    # given OAuth2Token with expired access_token
    api_client = FakeClass()
    api_client.set_oauth2_token = FakeMethod()
    refresh_token = "refresh-token-value"
    scope = [
        "email",
        "profile",
        "openid",
        "accounting.reports.read",
        "accounting.attachments.read",
        "accounting.settings",
        "accounting.settings.read",
        "accounting.attachments",
        "accounting.transactions",
        "accounting.journals.read",
        "accounting.transactions.read",
        "accounting.contacts",
        "accounting.contacts.read",
        "offline_access",
    ]
    new_token = {
        "id_token": "new-id-token-value",
        "access_token": "new-access-token-value",
        "expires_in": 1800,
        "expires_at": time.time() + 1800,
        "token_type": "Bearer",
        "refresh_token": "new-refresh-token-value",
        "scope": scope,
    }
    oauth2_token = OAuth2Token(client_id="client_id", client_secret="client_secret")
    oauth2_token.refresh_token = refresh_token
    oauth2_token.scope = scope
    oauth2_token.fetch_access_token = FakeMethod(return_value=new_token)
    # When refreshing access_token
    assert oauth2_token.refresh_access_token(api_client=api_client)
    # Then expected set new token function called
    assert len(oauth2_token.fetch_access_token.calls) == 1
    assert len(api_client.set_oauth2_token.calls) == 1
    call_args, call_kwargs = api_client.set_oauth2_token.calls[0]
    assert call_args == (new_token,)
    assert call_kwargs == {}
    # Then expected new valid access and refresh tokens set on oauth2_token
    assert oauth2_token.expires_at == new_token["expires_at"]
    assert oauth2_token.is_access_token_valid()
    assert oauth2_token.id_token == new_token["id_token"]
    assert oauth2_token.expires_in == new_token["expires_in"]
    assert oauth2_token.token_type == new_token["token_type"]
    assert oauth2_token.scope == new_token["scope"]
    assert oauth2_token.access_token == new_token["access_token"]
    assert oauth2_token.refresh_token == new_token["refresh_token"]


def test_auth2_fetch_access_token():
    # Given OAuth2Token with valid refresh_token
    oauth2_token = OAuth2Token()
    token_valid_from = time.time()
    scope = (
        "email profile openid accounting.reports.read "
        "accounting.attachments.read accounting.settings "
        "accounting.settings.read accounting.attachments "
        "accounting.transactions accounting.journals.read "
        "accounting.transactions.read accounting.contacts "
        "accounting.contacts.read offline_access"
    )
    new_token = {
        "id_token": "new-id-token-value",
        "access_token": "new-access-token-value",
        "expires_in": 1800,
        "token_type": "Bearer",
        "refresh_token": "new-refresh-token-value",
        "scope": scope,
    }
    oauth2_token.call_refresh_token_api = FakeMethod(return_value=new_token.copy())
    token_api = None
    # When we fetch new oauth2 token
    received_token = oauth2_token.fetch_access_token(
        token_api=token_api, token_valid_from=token_valid_from
    )
    # Then new token valid token to be received
    assert len(oauth2_token.call_refresh_token_api.calls) == 1
    assert received_token["id_token"] == new_token["id_token"]
    assert received_token["access_token"] == new_token["access_token"]
    assert received_token["expires_in"] == new_token["expires_in"]
    assert received_token["token_type"] == new_token["token_type"]
    assert received_token["refresh_token"] == new_token["refresh_token"]
    assert received_token["scope"] == scope.split()
    assert received_token["expires_at"] == token_valid_from + new_token["expires_in"]


def test_auth2_call_refresh_token_api(oauth2_refresh_token):
    # Given valid refresh token and client credentials
    oauth2_token = OAuth2Token()
    oauth2_token.update_token(**oauth2_refresh_token)
    token = {}
    token_api = FakeClass()
    token_api.refresh_token = FakeMethod(return_value=token)
    # When refresh token API endpoint called
    new_token = oauth2_token.call_refresh_token_api(token_api)
    # Then new oauth2 token received
    assert len(token_api.refresh_token.calls) == 1
    call_args, call_kwargs = token_api.refresh_token.calls[0]
    assert call_args == (oauth2_token.refresh_token, oauth2_token.scope)
    assert call_kwargs == {}
    assert new_token is token

def test_auth2_call_refresh_token_api_without_id_token(oauth2_token_without_id_token):
    # Given valid refresh token and client credentials without using OpenID scope (id_token absent)
    oauth2_token = OAuth2Token()
    oauth2_token.update_token(**oauth2_token_without_id_token)
    token = {}
    token_api = FakeClass()
    token_api.refresh_token = FakeMethod(return_value=token)
    # When refresh token API endpoint called
    new_token = oauth2_token.call_refresh_token_api(token_api)
    # Then new oauth2 token received
    assert len(token_api.refresh_token.calls) == 1
    call_args, call_kwargs = token_api.refresh_token.calls[0]
    assert call_args == (oauth2_token.refresh_token, oauth2_token.scope)
    assert call_kwargs == {}
    assert new_token is token


def test_token_api_refresh_token(
    xero_client_id, xero_client_secret, xero_scope, vcr, vcr_cassette_name
):
    # Given all oauth2 credential and refresh token
    api_client = ApiClient(pool_threads=1)
    token_api = TokenApi(api_client, xero_client_id, xero_client_secret)
    refresh_token = get_token_value("test_refresh_token") or "test-refresh-token"
    # When getting new token
    with vcr.use_cassette(vcr_cassette_name, record_mode="none") as cassette:
        token = token_api.refresh_token(refresh_token, xero_scope)
        assert cassette.all_played
    # uncomment to save new token for next run use
    # with open(join(dirname(__file__), "oauth2_token.py"), "w") as token_file:
    #     token_file.write("token = {!r}".format(token))
    # Then new oauth2 token received
    assert isinstance(token, dict)
    assert token.get("refresh_token")
    assert token["refresh_token"] != refresh_token
    assert token.get("access_token")
    assert token.get("expires_in")
    assert token.get("id_token")
    assert token.get("token_type")
    assert token.get("scope")
    assert token["scope"].split() == xero_scope



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Phone(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "phone_type": "str",
        "phone_number": "str",
        "phone_area_code": "str",
        "phone_country_code": "str",
    }

    attribute_map = {
        "phone_type": "PhoneType",
        "phone_number": "PhoneNumber",
        "phone_area_code": "PhoneAreaCode",
        "phone_country_code": "PhoneCountryCode",
    }

    def __init__(
        self,
        phone_type=None,
        phone_number=None,
        phone_area_code=None,
        phone_country_code=None,
    ):  # noqa: E501
        """Phone - a model defined in OpenAPI"""  # noqa: E501

        self._phone_type = None
        self._phone_number = None
        self._phone_area_code = None
        self._phone_country_code = None
        self.discriminator = None

        if phone_type is not None:
            self.phone_type = phone_type
        if phone_number is not None:
            self.phone_number = phone_number
        if phone_area_code is not None:
            self.phone_area_code = phone_area_code
        if phone_country_code is not None:
            self.phone_country_code = phone_country_code

    @property
    def phone_type(self):
        """Gets the phone_type of this Phone.  # noqa: E501


        :return: The phone_type of this Phone.  # noqa: E501
        :rtype: str
        """
        return self._phone_type

    @phone_type.setter
    def phone_type(self, phone_type):
        """Sets the phone_type of this Phone.


        :param phone_type: The phone_type of this Phone.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "DEFAULT",
            "DDI",
            "MOBILE",
            "FAX",
            "OFFICE",
            "None",
        ]  # noqa: E501

        if phone_type:
            if phone_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `phone_type` ({0}), must be one of {1}".format(  # noqa: E501
                        phone_type, allowed_values
                    )
                )

        self._phone_type = phone_type

    @property
    def phone_number(self):
        """Gets the phone_number of this Phone.  # noqa: E501

        max length = 50  # noqa: E501

        :return: The phone_number of this Phone.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this Phone.

        max length = 50  # noqa: E501

        :param phone_number: The phone_number of this Phone.  # noqa: E501
        :type: str
        """
        if phone_number is not None and len(phone_number) > 50:
            raise ValueError(
                "Invalid value for `phone_number`, "
                "length must be less than or equal to `50`"
            )  # noqa: E501

        self._phone_number = phone_number

    @property
    def phone_area_code(self):
        """Gets the phone_area_code of this Phone.  # noqa: E501

        max length = 10  # noqa: E501

        :return: The phone_area_code of this Phone.  # noqa: E501
        :rtype: str
        """
        return self._phone_area_code

    @phone_area_code.setter
    def phone_area_code(self, phone_area_code):
        """Sets the phone_area_code of this Phone.

        max length = 10  # noqa: E501

        :param phone_area_code: The phone_area_code of this Phone.  # noqa: E501
        :type: str
        """
        if phone_area_code is not None and len(phone_area_code) > 10:
            raise ValueError(
                "Invalid value for `phone_area_code`, "
                "length must be less than or equal to `10`"
            )  # noqa: E501

        self._phone_area_code = phone_area_code

    @property
    def phone_country_code(self):
        """Gets the phone_country_code of this Phone.  # noqa: E501

        max length = 20  # noqa: E501

        :return: The phone_country_code of this Phone.  # noqa: E501
        :rtype: str
        """
        return self._phone_country_code

    @phone_country_code.setter
    def phone_country_code(self, phone_country_code):
        """Sets the phone_country_code of this Phone.

        max length = 20  # noqa: E501

        :param phone_country_code: The phone_country_code of this Phone.  # noqa: E501
        :type: str
        """
        if phone_country_code is not None and len(phone_country_code) > 20:
            raise ValueError(
                "Invalid value for `phone_country_code`, "
                "length must be less than or equal to `20`"
            )  # noqa: E501

        self._phone_country_code = phone_country_code



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class ContactGroups(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"contact_groups": "list[ContactGroup]"}

    attribute_map = {"contact_groups": "ContactGroups"}

    def __init__(self, contact_groups=None):  # noqa: E501
        """ContactGroups - a model defined in OpenAPI"""  # noqa: E501

        self._contact_groups = None
        self.discriminator = None

        if contact_groups is not None:
            self.contact_groups = contact_groups

    @property
    def contact_groups(self):
        """Gets the contact_groups of this ContactGroups.  # noqa: E501


        :return: The contact_groups of this ContactGroups.  # noqa: E501
        :rtype: list[ContactGroup]
        """
        return self._contact_groups

    @contact_groups.setter
    def contact_groups(self, contact_groups):
        """Sets the contact_groups of this ContactGroups.


        :param contact_groups: The contact_groups of this ContactGroups.  # noqa: E501
        :type: list[ContactGroup]
        """

        self._contact_groups = contact_groups



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Benefit(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "id": "str",
        "name": "str",
        "category": "str",
        "liability_account_id": "str",
        "expense_account_id": "str",
        "standard_amount": "float",
        "percentage": "float",
        "calculation_type": "str",
        "current_record": "bool",
        "subject_to_nic": "bool",
        "subject_to_pension": "bool",
        "subject_to_tax": "bool",
        "is_calculating_on_qualifying_earnings": "bool",
        "show_balance_to_employee": "bool",
    }

    attribute_map = {
        "id": "id",
        "name": "name",
        "category": "category",
        "liability_account_id": "liabilityAccountId",
        "expense_account_id": "expenseAccountId",
        "standard_amount": "standardAmount",
        "percentage": "percentage",
        "calculation_type": "calculationType",
        "current_record": "currentRecord",
        "subject_to_nic": "subjectToNIC",
        "subject_to_pension": "subjectToPension",
        "subject_to_tax": "subjectToTax",
        "is_calculating_on_qualifying_earnings": "isCalculatingOnQualifyingEarnings",
        "show_balance_to_employee": "showBalanceToEmployee",
    }

    def __init__(
        self,
        id=None,
        name=None,
        category=None,
        liability_account_id=None,
        expense_account_id=None,
        standard_amount=None,
        percentage=None,
        calculation_type=None,
        current_record=None,
        subject_to_nic=None,
        subject_to_pension=None,
        subject_to_tax=None,
        is_calculating_on_qualifying_earnings=None,
        show_balance_to_employee=None,
    ):  # noqa: E501
        """Benefit - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._name = None
        self._category = None
        self._liability_account_id = None
        self._expense_account_id = None
        self._standard_amount = None
        self._percentage = None
        self._calculation_type = None
        self._current_record = None
        self._subject_to_nic = None
        self._subject_to_pension = None
        self._subject_to_tax = None
        self._is_calculating_on_qualifying_earnings = None
        self._show_balance_to_employee = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        self.category = category
        self.liability_account_id = liability_account_id
        self.expense_account_id = expense_account_id
        if standard_amount is not None:
            self.standard_amount = standard_amount
        self.percentage = percentage
        self.calculation_type = calculation_type
        if current_record is not None:
            self.current_record = current_record
        if subject_to_nic is not None:
            self.subject_to_nic = subject_to_nic
        if subject_to_pension is not None:
            self.subject_to_pension = subject_to_pension
        if subject_to_tax is not None:
            self.subject_to_tax = subject_to_tax
        if is_calculating_on_qualifying_earnings is not None:
            self.is_calculating_on_qualifying_earnings = (
                is_calculating_on_qualifying_earnings
            )
        if show_balance_to_employee is not None:
            self.show_balance_to_employee = show_balance_to_employee

    @property
    def id(self):
        """Gets the id of this Benefit.  # noqa: E501

        unique identifier in Xero  # noqa: E501

        :return: The id of this Benefit.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Benefit.

        unique identifier in Xero  # noqa: E501

        :param id: The id of this Benefit.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Benefit.  # noqa: E501

        Name of the employer pension  # noqa: E501

        :return: The name of this Benefit.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Benefit.

        Name of the employer pension  # noqa: E501

        :param name: The name of this Benefit.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def category(self):
        """Gets the category of this Benefit.  # noqa: E501

        Category type of the employer pension  # noqa: E501

        :return: The category of this Benefit.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Benefit.

        Category type of the employer pension  # noqa: E501

        :param category: The category of this Benefit.  # noqa: E501
        :type: str
        """
        if category is None:
            raise ValueError(
                "Invalid value for `category`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["StakeholderPension", "Other", "None"]  # noqa: E501

        if category:
            if category not in allowed_values:
                raise ValueError(
                    "Invalid value for `category` ({0}), must be one of {1}".format(  # noqa: E501
                        category, allowed_values
                    )
                )

        self._category = category

    @property
    def liability_account_id(self):
        """Gets the liability_account_id of this Benefit.  # noqa: E501

        Xero identifier for Liability Account  # noqa: E501

        :return: The liability_account_id of this Benefit.  # noqa: E501
        :rtype: str
        """
        return self._liability_account_id

    @liability_account_id.setter
    def liability_account_id(self, liability_account_id):
        """Sets the liability_account_id of this Benefit.

        Xero identifier for Liability Account  # noqa: E501

        :param liability_account_id: The liability_account_id of this Benefit.  # noqa: E501
        :type: str
        """
        if liability_account_id is None:
            raise ValueError(
                "Invalid value for `liability_account_id`, must not be `None`"
            )  # noqa: E501

        self._liability_account_id = liability_account_id

    @property
    def expense_account_id(self):
        """Gets the expense_account_id of this Benefit.  # noqa: E501

        Xero identifier for Expense Account  # noqa: E501

        :return: The expense_account_id of this Benefit.  # noqa: E501
        :rtype: str
        """
        return self._expense_account_id

    @expense_account_id.setter
    def expense_account_id(self, expense_account_id):
        """Sets the expense_account_id of this Benefit.

        Xero identifier for Expense Account  # noqa: E501

        :param expense_account_id: The expense_account_id of this Benefit.  # noqa: E501
        :type: str
        """
        if expense_account_id is None:
            raise ValueError(
                "Invalid value for `expense_account_id`, must not be `None`"
            )  # noqa: E501

        self._expense_account_id = expense_account_id

    @property
    def standard_amount(self):
        """Gets the standard_amount of this Benefit.  # noqa: E501

        Standard amount of the employer pension  # noqa: E501

        :return: The standard_amount of this Benefit.  # noqa: E501
        :rtype: float
        """
        return self._standard_amount

    @standard_amount.setter
    def standard_amount(self, standard_amount):
        """Sets the standard_amount of this Benefit.

        Standard amount of the employer pension  # noqa: E501

        :param standard_amount: The standard_amount of this Benefit.  # noqa: E501
        :type: float
        """

        self._standard_amount = standard_amount

    @property
    def percentage(self):
        """Gets the percentage of this Benefit.  # noqa: E501

        Percentage of gross of the employer pension  # noqa: E501

        :return: The percentage of this Benefit.  # noqa: E501
        :rtype: float
        """
        return self._percentage

    @percentage.setter
    def percentage(self, percentage):
        """Sets the percentage of this Benefit.

        Percentage of gross of the employer pension  # noqa: E501

        :param percentage: The percentage of this Benefit.  # noqa: E501
        :type: float
        """
        if percentage is None:
            raise ValueError(
                "Invalid value for `percentage`, must not be `None`"
            )  # noqa: E501

        self._percentage = percentage

    @property
    def calculation_type(self):
        """Gets the calculation_type of this Benefit.  # noqa: E501

        Calculation Type of the employer pension (FixedAmount or PercentageOfGross).  # noqa: E501

        :return: The calculation_type of this Benefit.  # noqa: E501
        :rtype: str
        """
        return self._calculation_type

    @calculation_type.setter
    def calculation_type(self, calculation_type):
        """Sets the calculation_type of this Benefit.

        Calculation Type of the employer pension (FixedAmount or PercentageOfGross).  # noqa: E501

        :param calculation_type: The calculation_type of this Benefit.  # noqa: E501
        :type: str
        """
        if calculation_type is None:
            raise ValueError(
                "Invalid value for `calculation_type`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["FixedAmount", "PercentageOfGross", "None"]  # noqa: E501

        if calculation_type:
            if calculation_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `calculation_type` ({0}), must be one of {1}".format(  # noqa: E501
                        calculation_type, allowed_values
                    )
                )

        self._calculation_type = calculation_type

    @property
    def current_record(self):
        """Gets the current_record of this Benefit.  # noqa: E501

        Identifier of a record is active or not.  # noqa: E501

        :return: The current_record of this Benefit.  # noqa: E501
        :rtype: bool
        """
        return self._current_record

    @current_record.setter
    def current_record(self, current_record):
        """Sets the current_record of this Benefit.

        Identifier of a record is active or not.  # noqa: E501

        :param current_record: The current_record of this Benefit.  # noqa: E501
        :type: bool
        """

        self._current_record = current_record

    @property
    def subject_to_nic(self):
        """Gets the subject_to_nic of this Benefit.  # noqa: E501

        Identifier of subject To NIC  # noqa: E501

        :return: The subject_to_nic of this Benefit.  # noqa: E501
        :rtype: bool
        """
        return self._subject_to_nic

    @subject_to_nic.setter
    def subject_to_nic(self, subject_to_nic):
        """Sets the subject_to_nic of this Benefit.

        Identifier of subject To NIC  # noqa: E501

        :param subject_to_nic: The subject_to_nic of this Benefit.  # noqa: E501
        :type: bool
        """

        self._subject_to_nic = subject_to_nic

    @property
    def subject_to_pension(self):
        """Gets the subject_to_pension of this Benefit.  # noqa: E501

        Identifier of subject To pension  # noqa: E501

        :return: The subject_to_pension of this Benefit.  # noqa: E501
        :rtype: bool
        """
        return self._subject_to_pension

    @subject_to_pension.setter
    def subject_to_pension(self, subject_to_pension):
        """Sets the subject_to_pension of this Benefit.

        Identifier of subject To pension  # noqa: E501

        :param subject_to_pension: The subject_to_pension of this Benefit.  # noqa: E501
        :type: bool
        """

        self._subject_to_pension = subject_to_pension

    @property
    def subject_to_tax(self):
        """Gets the subject_to_tax of this Benefit.  # noqa: E501

        Identifier of subject To Tax  # noqa: E501

        :return: The subject_to_tax of this Benefit.  # noqa: E501
        :rtype: bool
        """
        return self._subject_to_tax

    @subject_to_tax.setter
    def subject_to_tax(self, subject_to_tax):
        """Sets the subject_to_tax of this Benefit.

        Identifier of subject To Tax  # noqa: E501

        :param subject_to_tax: The subject_to_tax of this Benefit.  # noqa: E501
        :type: bool
        """

        self._subject_to_tax = subject_to_tax

    @property
    def is_calculating_on_qualifying_earnings(self):
        """Gets the is_calculating_on_qualifying_earnings of this Benefit.  # noqa: E501

        Identifier of calculating on qualifying earnings  # noqa: E501

        :return: The is_calculating_on_qualifying_earnings of this Benefit.  # noqa: E501
        :rtype: bool
        """
        return self._is_calculating_on_qualifying_earnings

    @is_calculating_on_qualifying_earnings.setter
    def is_calculating_on_qualifying_earnings(
        self, is_calculating_on_qualifying_earnings
    ):
        """Sets the is_calculating_on_qualifying_earnings of this Benefit.

        Identifier of calculating on qualifying earnings  # noqa: E501

        :param is_calculating_on_qualifying_earnings: The is_calculating_on_qualifying_earnings of this Benefit.  # noqa: E501
        :type: bool
        """

        self._is_calculating_on_qualifying_earnings = (
            is_calculating_on_qualifying_earnings
        )

    @property
    def show_balance_to_employee(self):
        """Gets the show_balance_to_employee of this Benefit.  # noqa: E501

        display the balance to employee  # noqa: E501

        :return: The show_balance_to_employee of this Benefit.  # noqa: E501
        :rtype: bool
        """
        return self._show_balance_to_employee

    @show_balance_to_employee.setter
    def show_balance_to_employee(self, show_balance_to_employee):
        """Sets the show_balance_to_employee of this Benefit.

        display the balance to employee  # noqa: E501

        :param show_balance_to_employee: The show_balance_to_employee of this Benefit.  # noqa: E501
        :type: bool
        """

        self._show_balance_to_employee = show_balance_to_employee



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class CISSetting(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"cis_enabled": "bool", "rate": "float"}

    attribute_map = {"cis_enabled": "CISEnabled", "rate": "Rate"}

    def __init__(self, cis_enabled=None, rate=None):  # noqa: E501
        """CISSetting - a model defined in OpenAPI"""  # noqa: E501

        self._cis_enabled = None
        self._rate = None
        self.discriminator = None

        if cis_enabled is not None:
            self.cis_enabled = cis_enabled
        if rate is not None:
            self.rate = rate

    @property
    def cis_enabled(self):
        """Gets the cis_enabled of this CISSetting.  # noqa: E501

        Boolean that describes if the contact is a CIS Subcontractor  # noqa: E501

        :return: The cis_enabled of this CISSetting.  # noqa: E501
        :rtype: bool
        """
        return self._cis_enabled

    @cis_enabled.setter
    def cis_enabled(self, cis_enabled):
        """Sets the cis_enabled of this CISSetting.

        Boolean that describes if the contact is a CIS Subcontractor  # noqa: E501

        :param cis_enabled: The cis_enabled of this CISSetting.  # noqa: E501
        :type: bool
        """

        self._cis_enabled = cis_enabled

    @property
    def rate(self):
        """Gets the rate of this CISSetting.  # noqa: E501

        CIS Deduction rate for the contact if he is a subcontractor. If the contact is not CISEnabled, then the rate is not returned  # noqa: E501

        :return: The rate of this CISSetting.  # noqa: E501
        :rtype: float
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        """Sets the rate of this CISSetting.

        CIS Deduction rate for the contact if he is a subcontractor. If the contact is not CISEnabled, then the rate is not returned  # noqa: E501

        :param rate: The rate of this CISSetting.  # noqa: E501
        :type: float
        """

        self._rate = rate



# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class StatutoryDeductionLine(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "statutory_deduction_type_id": "str",
        "amount": "float",
        "fixed_amount": "float",
        "manual_adjustment": "bool",
    }

    attribute_map = {
        "statutory_deduction_type_id": "statutoryDeductionTypeID",
        "amount": "amount",
        "fixed_amount": "fixedAmount",
        "manual_adjustment": "manualAdjustment",
    }

    def __init__(
        self,
        statutory_deduction_type_id=None,
        amount=None,
        fixed_amount=None,
        manual_adjustment=None,
    ):  # noqa: E501
        """StatutoryDeductionLine - a model defined in OpenAPI"""  # noqa: E501

        self._statutory_deduction_type_id = None
        self._amount = None
        self._fixed_amount = None
        self._manual_adjustment = None
        self.discriminator = None

        if statutory_deduction_type_id is not None:
            self.statutory_deduction_type_id = statutory_deduction_type_id
        if amount is not None:
            self.amount = amount
        if fixed_amount is not None:
            self.fixed_amount = fixed_amount
        if manual_adjustment is not None:
            self.manual_adjustment = manual_adjustment

    @property
    def statutory_deduction_type_id(self):
        """Gets the statutory_deduction_type_id of this StatutoryDeductionLine.  # noqa: E501

        Xero identifier for payroll statutory deduction type  # noqa: E501

        :return: The statutory_deduction_type_id of this StatutoryDeductionLine.  # noqa: E501
        :rtype: str
        """
        return self._statutory_deduction_type_id

    @statutory_deduction_type_id.setter
    def statutory_deduction_type_id(self, statutory_deduction_type_id):
        """Sets the statutory_deduction_type_id of this StatutoryDeductionLine.

        Xero identifier for payroll statutory deduction type  # noqa: E501

        :param statutory_deduction_type_id: The statutory_deduction_type_id of this StatutoryDeductionLine.  # noqa: E501
        :type: str
        """

        self._statutory_deduction_type_id = statutory_deduction_type_id

    @property
    def amount(self):
        """Gets the amount of this StatutoryDeductionLine.  # noqa: E501

        The amount of the statutory deduction line  # noqa: E501

        :return: The amount of this StatutoryDeductionLine.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this StatutoryDeductionLine.

        The amount of the statutory deduction line  # noqa: E501

        :param amount: The amount of this StatutoryDeductionLine.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def fixed_amount(self):
        """Gets the fixed_amount of this StatutoryDeductionLine.  # noqa: E501

        Fixed Amount  # noqa: E501

        :return: The fixed_amount of this StatutoryDeductionLine.  # noqa: E501
        :rtype: float
        """
        return self._fixed_amount

    @fixed_amount.setter
    def fixed_amount(self, fixed_amount):
        """Sets the fixed_amount of this StatutoryDeductionLine.

        Fixed Amount  # noqa: E501

        :param fixed_amount: The fixed_amount of this StatutoryDeductionLine.  # noqa: E501
        :type: float
        """

        self._fixed_amount = fixed_amount

    @property
    def manual_adjustment(self):
        """Gets the manual_adjustment of this StatutoryDeductionLine.  # noqa: E501

        Identifies if the tax line is a manual adjustment  # noqa: E501

        :return: The manual_adjustment of this StatutoryDeductionLine.  # noqa: E501
        :rtype: bool
        """
        return self._manual_adjustment

    @manual_adjustment.setter
    def manual_adjustment(self, manual_adjustment):
        """Sets the manual_adjustment of this StatutoryDeductionLine.

        Identifies if the tax line is a manual adjustment  # noqa: E501

        :param manual_adjustment: The manual_adjustment of this StatutoryDeductionLine.  # noqa: E501
        :type: bool
        """

        self._manual_adjustment = manual_adjustment



# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class LeavePeriod(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "period_start_date": "date",
        "period_end_date": "date",
        "number_of_units": "float",
        "period_status": "str",
    }

    attribute_map = {
        "period_start_date": "periodStartDate",
        "period_end_date": "periodEndDate",
        "number_of_units": "numberOfUnits",
        "period_status": "periodStatus",
    }

    def __init__(
        self,
        period_start_date=None,
        period_end_date=None,
        number_of_units=None,
        period_status=None,
    ):  # noqa: E501
        """LeavePeriod - a model defined in OpenAPI"""  # noqa: E501

        self._period_start_date = None
        self._period_end_date = None
        self._number_of_units = None
        self._period_status = None
        self.discriminator = None

        if period_start_date is not None:
            self.period_start_date = period_start_date
        if period_end_date is not None:
            self.period_end_date = period_end_date
        if number_of_units is not None:
            self.number_of_units = number_of_units
        if period_status is not None:
            self.period_status = period_status

    @property
    def period_start_date(self):
        """Gets the period_start_date of this LeavePeriod.  # noqa: E501

        The Pay Period Start Date (YYYY-MM-DD)  # noqa: E501

        :return: The period_start_date of this LeavePeriod.  # noqa: E501
        :rtype: date
        """
        return self._period_start_date

    @period_start_date.setter
    def period_start_date(self, period_start_date):
        """Sets the period_start_date of this LeavePeriod.

        The Pay Period Start Date (YYYY-MM-DD)  # noqa: E501

        :param period_start_date: The period_start_date of this LeavePeriod.  # noqa: E501
        :type: date
        """

        self._period_start_date = period_start_date

    @property
    def period_end_date(self):
        """Gets the period_end_date of this LeavePeriod.  # noqa: E501

        The Pay Period End Date (YYYY-MM-DD)  # noqa: E501

        :return: The period_end_date of this LeavePeriod.  # noqa: E501
        :rtype: date
        """
        return self._period_end_date

    @period_end_date.setter
    def period_end_date(self, period_end_date):
        """Sets the period_end_date of this LeavePeriod.

        The Pay Period End Date (YYYY-MM-DD)  # noqa: E501

        :param period_end_date: The period_end_date of this LeavePeriod.  # noqa: E501
        :type: date
        """

        self._period_end_date = period_end_date

    @property
    def number_of_units(self):
        """Gets the number_of_units of this LeavePeriod.  # noqa: E501

        The Number of Units for the leave  # noqa: E501

        :return: The number_of_units of this LeavePeriod.  # noqa: E501
        :rtype: float
        """
        return self._number_of_units

    @number_of_units.setter
    def number_of_units(self, number_of_units):
        """Sets the number_of_units of this LeavePeriod.

        The Number of Units for the leave  # noqa: E501

        :param number_of_units: The number_of_units of this LeavePeriod.  # noqa: E501
        :type: float
        """

        self._number_of_units = number_of_units

    @property
    def period_status(self):
        """Gets the period_status of this LeavePeriod.  # noqa: E501

        Period Status  # noqa: E501

        :return: The period_status of this LeavePeriod.  # noqa: E501
        :rtype: str
        """
        return self._period_status

    @period_status.setter
    def period_status(self, period_status):
        """Sets the period_status of this LeavePeriod.

        Period Status  # noqa: E501

        :param period_status: The period_status of this LeavePeriod.  # noqa: E501
        :type: str
        """
        allowed_values = ["Approved", "Completed", "None"]  # noqa: E501

        if period_status:
            if period_status not in allowed_values:
                raise ValueError(
                    "Invalid value for `period_status` ({0}), must be one of {1}".format(  # noqa: E501
                        period_status, allowed_values
                    )
                )

        self._period_status = period_status
